# Copyright (c) Meta Platforms, Inc. and affiliates.

from threatexchange.extensions.manifest import ThreatExchangeExtensionManifest
from threatexchange.extensions.tlsh.text_tlsh import TextTLSHSignal


TX_MANIFEST = ThreatExchangeExtensionManifest(
    signal_types=(TextTLSHSignal,),
)



# Copyright (c) Meta Platforms, Inc. and affiliates.

import unittest

import threatexchange.common


class TestCommon(unittest.TestCase):
    def test_camel_case_to_underscore(self):
        assert threatexchange.common.camel_case_to_underscore("AbcXyz") == "abc_xyz"
